@@ -8,7 +8,7 @@ use CPAN::Audit::Version;
 use CPAN::Audit::Query;
 use CPAN::Audit::DB;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 sub new {
     my $class = shift;
@@ -105,7 +105,18 @@ sub command {
     elsif ( $command eq 'installed' ) {
         $self->stdout('Collecting all installed modules. This can take a while...');
 
-        my @deps = CPAN::Audit::Installed->new( db => $self->{db} )->find(@ARGV);
+        my @deps = CPAN::Audit::Installed->new(
+            db => $self->{db},
+            $self->{verbose}
+            ? (
+                cb => sub {
+                    my ($info) = @_;
+
+                    $self->stdout('%s: %s-%s', $info->{path}, $info->{distname}, $info->{version});
+                }
+              )
+            : ()
+        )->find(@ARGV);
 
         foreach my $dep (@deps) {
             my $dist = $dep->{dist}
